require 'rest_client'
require 'json'


class Beacon
  attr_accessor :api_key, :secret_key, :host, :version
  
  
  def initialize(api_key, secret_key, options = {})
    @api_key    = api_key
    @secret_key = secret_key
    
    @host    = options[:host]    || 'api.beaconpush.com'
    @headers = options[:headers] || {}
    @version = options[:version] || '1.0.0'
  end
  
  
  def publish(channel, data)
    RestClient.post("#{base_url}/channels/#{channel}", JSON.dump(data), headers)
    data
  end
  
  
  def users_count
    response = RestClient.get("#{base_url}/users", headers)
    JSON.load(response)['online']
  end
  
  
  def online?(username)
    response = RestClient.get("#{base_url}/users/#{username}", headers)
    JSON.load(response)['status'] == 200
  end
  
  
  def logout(username)
    RestClient.delete("#{base_url}/users/#{username}", headers)
    username
  end
  
  
  def users(channel)
    response = RestClient.get("#{base_url}/channels/#{channel}", headers)
    JSON.load(response)['users']
  end
  
  
  def whisper(username, data)
    RestClient.post("#{base_url}/users/#{username}", JSON.dump(data), headers)
    data
  end
  
  
  private
  
  def base_url
    "http://#{host}/#{version}/#{api_key}"
  end
  
  
  def headers
    { 'X-Beacon-Secret-Key' => secret_key }.merge(@headers)
  end
end
